import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DatabaseMigrationServiceClient";
import { DeleteReplicationSubnetGroupMessage, DeleteReplicationSubnetGroupResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteReplicationSubnetGroupCommand}.
 */
export interface DeleteReplicationSubnetGroupCommandInput extends DeleteReplicationSubnetGroupMessage {
}
/**
 * @public
 *
 * The output of {@link DeleteReplicationSubnetGroupCommand}.
 */
export interface DeleteReplicationSubnetGroupCommandOutput extends DeleteReplicationSubnetGroupResponse, __MetadataBearer {
}
declare const DeleteReplicationSubnetGroupCommand_base: {
    new (input: DeleteReplicationSubnetGroupCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteReplicationSubnetGroupCommandInput, DeleteReplicationSubnetGroupCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteReplicationSubnetGroupCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteReplicationSubnetGroupCommandInput, DeleteReplicationSubnetGroupCommandOutput, DatabaseMigrationServiceClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes a subnet group.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DatabaseMigrationServiceClient, DeleteReplicationSubnetGroupCommand } from "@aws-sdk/client-database-migration-service"; // ES Modules import
 * // const { DatabaseMigrationServiceClient, DeleteReplicationSubnetGroupCommand } = require("@aws-sdk/client-database-migration-service"); // CommonJS import
 * const client = new DatabaseMigrationServiceClient(config);
 * const input = { // DeleteReplicationSubnetGroupMessage
 *   ReplicationSubnetGroupIdentifier: "STRING_VALUE", // required
 * };
 * const command = new DeleteReplicationSubnetGroupCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteReplicationSubnetGroupCommandInput - {@link DeleteReplicationSubnetGroupCommandInput}
 * @returns {@link DeleteReplicationSubnetGroupCommandOutput}
 * @see {@link DeleteReplicationSubnetGroupCommandInput} for command's `input` shape.
 * @see {@link DeleteReplicationSubnetGroupCommandOutput} for command's `response` shape.
 * @see {@link DatabaseMigrationServiceClientResolvedConfig | config} for DatabaseMigrationServiceClient's `config` shape.
 *
 * @throws {@link InvalidResourceStateFault} (client fault)
 *  <p>The resource is in a state that prevents it from being used for database migration.</p>
 *
 * @throws {@link ResourceNotFoundFault} (client fault)
 *  <p>The resource could not be found.</p>
 *
 * @throws {@link DatabaseMigrationServiceServiceException}
 * <p>Base exception class for all service exceptions from DatabaseMigrationService service.</p>
 *
 * @public
 * @example Delete Replication Subnet Group
 * ```javascript
 * // Deletes a replication subnet group.
 * const input = {
 *   "ReplicationSubnetGroupIdentifier": "us-west-2ab-vpc-215ds366"
 * };
 * const command = new DeleteReplicationSubnetGroupCommand(input);
 * await client.send(command);
 * // example id: delete-replication-subnet-group-1481752728597
 * ```
 *
 */
export declare class DeleteReplicationSubnetGroupCommand extends DeleteReplicationSubnetGroupCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteReplicationSubnetGroupMessage;
            output: {};
        };
        sdk: {
            input: DeleteReplicationSubnetGroupCommandInput;
            output: DeleteReplicationSubnetGroupCommandOutput;
        };
    };
}
